<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Http\Request;
use Validator;
use Auth;
use Illuminate\Support\Facades\Hash;
use Tymon\JWTAuth\Exceptions\JWTException;
use Tymon\JWTAuth\Facades\JWTAuth;

class UserController extends Controller
{
    public function register(Request $request)
    {
        $rules = [
            'fname'=>'required|string',
            'lname'=>'required|string',
            'phone'=>'required|unique:users|numeric',
            'email'=> 'required|email|unique:users',
            'password'=>'required|min:6|string'
        ];
        $validator = Validator::make($request->all(),$rules);
        if($validator->fails()){
            $inputs = array_keys($validator->errors()->toArray());
            return response()->json([
                'status'=>false,
                'Validations'=>$validator->errors()
            ]);
        }
        $user = new User();
        $user->CreateUser($request->fname,$request->lname,$request->phone,$request->email,$request->password);
        return response()->json([
            'status'=>true,
            'Msg'=>'successfully registered'
        ]);
    }

    public function login(Request $request){
        $cred = $request->only('email','password');
        $token = null;

        $rules = [
            "email"=>"required|exists:users,email",
            "password"=>"required"
        ];
        $validator = Validator::make($request->all(),$rules);

        if($validator->fails()){
            $inputs = array_keys($validator->errors()->toArray());
            return response()->json([
                'status'=>false,
                'Msg'=>$validator->errors()->first()
            ]);
        }

        if(!$token = JWTAuth::attempt($cred)){
            return response()->json([
                'status'=> false,
                'Msg'=> 'Password Not correct'
            ]);
        }
        $user = Auth::user();
        return response()->json([
            'status'=>true,
            'token'=>$token,
            'user'=>$user
        ]);
    }


}
